import os
import time
from pythoni2c import read_address
from pythoni2c import write_address
from pythoni2c import readU8
from pythoni2c import write8
from pythoni2c import signed



#Read and process all calibration registers from BMP180

AC1_MSB = int(read_address(0x77,0xAA),0)
AC1_LSB = int(read_address(0x77,0xAB),0)
AC1 = signed((AC1_MSB << 8) + AC1_LSB)
AC2_MSB = int(read_address(0x77,0xAC),0)
AC2_LSB = int(read_address(0x77,0xAD),0)
AC2 = signed((AC2_MSB << 8) + AC2_LSB)
AC3_MSB = int(read_address(0x77,0xAE),0)
AC3_LSB = int(read_address(0x77,0xAF),0)
AC3 = signed((AC3_MSB << 8) + AC3_LSB)
AC4_MSB = int(read_address(0x77,0xB0),0)
AC4_LSB = int(read_address(0x77,0xB1),0)
AC4 = (AC4_MSB << 8) + AC4_LSB
AC5_MSB = int(read_address(0x77,0xB2),0)
AC5_LSB = int(read_address(0x77,0xB3),0)
AC5 = (AC5_MSB << 8) + AC5_LSB
AC6_MSB = int(read_address(0x77,0xB4),0)
AC6_LSB = int(read_address(0x77,0xB5),0)
AC6 = (AC6_MSB << 8) + AC6_LSB
B1_MSB = int(read_address(0x77,0xB6),0)
B1_LSB = int(read_address(0x77,0xB7),0)
B1 = signed((B1_MSB << 8) + B1_LSB)
B2_MSB = int(read_address(0x77,0xB8),0)
B2_LSB = int(read_address(0x77,0xB9),0)
B2 = signed((B2_MSB << 8) + B2_LSB)
MB_MSB = int(read_address(0x77,0xBA),0)
MB_LSB = int(read_address(0x77,0xBB),0)
MB = signed((MB_MSB << 8) + MB_LSB)
MC_MSB = int(read_address(0x77,0xBC),0)
MC_LSB = int(read_address(0x77,0xBD),0)
MC = signed((MC_MSB << 8) + MC_LSB)
MD_MSB = int(read_address(0x77,0xBE),0)
MD_LSB = int(read_address(0x77,0xBF),0)
MD = signed((MD_MSB << 8) + MD_LSB)
OSS = 0


#Read temperature from BMP180

def read_temp():
	write_address(0x77,0xF4,0x2E)
	time.sleep(0.005)
	UT_MSB = int(read_address(0x77,0xF6),0)
	#print '0xF6 is ',UT_MSB
	UT_LSB = int(read_address(0x77,0xF7),0)
	#print '0xF7 is ',UT_LSB
	UT = (UT_MSB << 8) + UT_LSB
	X1 = ((UT - AC6) * AC5) >> 15
	X2 = (MC << 11) / (X1 + MD)
	B5 = X1 + X2
	T = ((B5 + 8) >> 4) / 10.0
	return T

#Read pressure from BMP180(output is in hPa)

def read_pressure():
	write8(0x77,0xF4, 0x34 + (OSS << 6))
	if OSS == 0:
		time.sleep(0.005)
	elif OSS == 2:
		time.sleep(0.014)
	elif OSS == 3:
		time.sleep(0.026)
	else:
		time.sleep(0.008)
	msb = readU8(0x77,0xF6)
	lsb = readU8(0x77,0xF7)
	xlsb = readU8(0x77,0xF8)
	UP = ((msb << 16) + (lsb << 8) + xlsb) >> (8 - OSS)
        write_address(0x77,0xF4,0x2E)
        time.sleep(0.005)
        UT_MSB = int(read_address(0x77,0xF6),0)
        UT_LSB = int(read_address(0x77,0xF7),0)
        UT = (UT_MSB << 8) + UT_LSB
        X1 = ((UT - AC6) * AC5) >> 15
        X2 = (MC << 11) / (X1 + MD)
        B5 = X1 + X2
	B6 = B5 - 4000
	X1 = (B2 * (B6^2) >> 12) >> 11
	X2 = (AC2 * B6) >> 11
	X3 = X1 + X2
	B3 = (((AC1 * 4 + X3) << OSS) + 2) / 4
	X1 = (AC3 * B6) >> 13
	X2 = (B1 * ((B6 * B6) >> 12)) >> 16
	X3 = ((X1 + X2) + 2) >> 2
	B4 = (AC4 * (X3 + 32768)) >> 15
	B7 = (UP - B3) * (50000 >> OSS)
	if B7 < 0x80000000:
		p = (B7 * 2) / B4
	else:
		p = (B7 / B4) * 2
	X1 = (p >> 8) * (p >> 8)
	X1 = (X1 * 3038) >> 16
	X2 = (-7357 * p) >> 16
	p = p + ((X1 + X2 + 3791) >> 4)
	p = p / 100
	return p		


def value_out(value,file):
	l='echo '+str(value)+' > '+str(file)
	p = os.popen(l)
	s = p.readline()
	p.close()



xa = 1

print 'Use cat /root/Temp and cat /root/Pressure to check values...'

while xa==1:
	#print 'Temp is :',read_temp(),'C'
	value_out(read_temp(),'/root/Temp')
	#print 'Pressure is :',read_pressure(),'hPa'
	value_out(read_pressure(),'/root/Pressure')
	time.sleep(5)


